pub fn test_transactions(
network: &Network,
) -> impl DoubleEndedIterator<Item = (Height, Arc<Transaction>)>Expand description
Iterate over transactions in the block test vectors for the specified network.
pub fn test_transactions(
network: &Network,
) -> impl DoubleEndedIterator<Item = (Height, Arc<Transaction>)>Iterate over transactions in the block test vectors for the specified network.